# Python CovRegpy Package


Regularised covariance regression software based on Hoff and Niu (2012) - see https://arxiv.org/pdf/1102.5721.



This package was developed out of research performed by Cole van Jaarsveldt, Gareth W. Peters, Matthew Ames, and Mike Chantler. This package was built entirely using Python 3.11.5 - Python guarantees backwards compatibility which should ensure that this software package functions as expected on all future Python versions. See:



van Jaarsveldt, C., Peters, G., Ames, M., & Chantler, M. (2024) Package CovRegpy: Regularized covariance regression and forecasting in Python. Annals of Actuarial Science, First View. doi:10.1017/S1748499524000101 url: https://dx.doi.org/10.1017/S1748499524000101


